@@ -15,13 +15,13 @@
 import datetime
 import json
 from collections import namedtuple
-from typing import List, Optional
+from typing import Dict, List, Optional
 
 # Third-party imports
 # -------------------
 from fastapi.exceptions import HTTPException
 from pydal.validators import CRYPT
-from sqlalchemy import and_, func, update
+from sqlalchemy import and_, distinct, func, update
 from sqlalchemy.sql import select, text
 
 from . import schemas
@@ -118,6 +118,45 @@ async def count_useinfo_for(
         return res.all()
 
 
+async def fetch_page_activity_counts(
+    chapter: str, subchapter: str, base_course: str, course_name: str, username: str
+) -> Dict[str, int]:
+    """
+    Used for the progress bar at the bottom of each page.  This function
+    finds all of the components for a particular page (chaper/subchapter)
+    and then finds out which of those elements the student has interacted
+    with.  It returns a dictionary of {divid: 0/1}
+    """
+
+    where_clause_common = (
+        (Question.subchapter == subchapter)
+        & (Question.chapter == chapter)
+        & (Question.from_source == True)  # noqa: E712
+        & ((Question.optional == False) | (Question.optional == None))
+        & (Question.base_course == base_course)
+    )
+
+    query = select(Question).where(where_clause_common)
+
+    async with async_session() as session:
+        page_divids = await session.execute(query)
+    rslogger.debug(f"PDVD {page_divids}")
+    div_counts = {q.name: 0 for q in page_divids.scalars()}
+    query = select(distinct(Useinfo.div_id)).where(
+        where_clause_common
+        & (Question.name == Useinfo.div_id)
+        & (Useinfo.course_id == course_name)
+        & (Useinfo.sid == username)
+    )
+    async with async_session() as session:
+        sid_counts = await session.execute(query)
+
+    for row in sid_counts.scalars():
+        div_counts[row.div_id] = 1
+
+    return div_counts
+
+
 async def fetch_poll_summary(div_id: str, course_name: str) -> List[tuple]:
     """
     find the last answer for each student and then aggregate
@@ -243,11 +282,10 @@ async def fetch_base_course(base_course: str) -> CoursesValidator:
         return CoursesValidator.from_orm(base_course)
 
 
-async def create_course(course_info: CoursesValidator) -> CoursesValidator:
+async def create_course(course_info: CoursesValidator) -> None:
     new_course = Courses(**course_info.dict())
     async with async_session.begin() as session:
         session.add(new_course)
-    return CoursesValidator.from_orm(new_course)
 
 
 # auth_user
@@ -404,6 +442,7 @@ async def create_initial_courses_users():
                 downloads_enabled=False,
                 courselevel="",
                 institution="",
+                new_server=False,
             )
             await create_course(new_course)
         # make a user
