@@ -32,7 +32,9 @@ else:
 
 # The polling in `../../test/test_runestone_components.py` produces a HUGE amount of output when echo is true.
 extra_settings = (
-    {} if settings.book_server_config == BookServerConfig.test else dict(echo=True)
+    {}
+    if settings.book_server_config == BookServerConfig.test
+    else dict(echo=settings.db_echo)
 )
 engine = create_async_engine(
     settings.database_url, connect_args=connect_args, **extra_settings
